@@ -56,15 +56,14 @@ def _getFromYAML(path: str):
     return val
 
 
-def get(key: str, name: str, default: str = None):
-    path = _buildPath(key, name)
+def get(key: str, default: str = None):
 
-    val = _getFromENV(path)
+    val = _getFromENV(key)
     if val is not None:
         return val
 
     try:
-        val = _getFromYAML(path).get()
+        val = _getFromYAML(key).get()
         if val is not None:
             return val
 
@@ -79,9 +78,9 @@ def get(key: str, name: str, default: str = None):
 
 def _attributesOfObject(obj: object) -> list:
     attributes = [attr for attr in vars(
-        type(obj))["__annotations__"] if attr[0] is not '_']
-    attributes += [attr for attr in vars(type(obj)) if attr[0] is not '_']
-    attributes += [attr for attr in vars(obj) if attr[0] is not '_']
+        type(obj))["__annotations__"] if attr[0] != '_']
+    attributes += [attr for attr in vars(type(obj)) if attr[0] != '_']
+    attributes += [attr for attr in vars(obj) if attr[0] != '_']
 
     return list(dict.fromkeys(attributes))
 
@@ -133,6 +132,6 @@ def getObject(obj: object, path: str = None) -> object:
         if _isObject(obj, attr):
             vars(obj)[attr] = getObject(val, "{}.{}".format(basepath, attr))
         else:
-            vars(obj)[attr] = get(basepath, attr, val)
+            vars(obj)[attr] = get(_buildPath(basepath, attr), val)
 
     return obj
